@@ -349,7 +349,6 @@ class CreateRecTaskRequest(AbstractModel):
 • 16k_en_edu 英文教育；
 • 16k_zh_medical  医疗；
 • 16k_th 泰语；
-• 16k_zh_dialect：多方言，支持23种方言。
         :type EngineModelType: str
         :param ChannelNum: 识别声道数。1：单声道（非电话场景，直接选择单声道即可，忽略音频声道数）；2：双声道（仅支持8k_zh电话场景，双声道应分别对应通话双方）。注意：双声道的电话音频已物理分离说话人，无需再开启说话人分离功能。
         :type ChannelNum: int
@@ -1163,7 +1162,7 @@ class SentenceRecognitionRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ProjectId: 腾讯云项目 ID，可填 0，总长度不超过 1024 字节。
+        :param ProjectId: 腾讯云项目 ID，废弃参数，默认填写0即可。
         :type ProjectId: int
         :param SubServiceType: 子服务类型。2： 一句话识别。
         :type SubServiceType: int
@@ -1177,13 +1176,12 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
 • 16k_zh_medical：16k 医疗；
-• 16k_zh_dialect：多方言，支持23种方言。
         :type EngSerViceType: str
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
         :param VoiceFormat: 识别音频的音频格式，支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac。
         :type VoiceFormat: str
-        :param UsrAudioKey: 用户端对此任务的唯一标识，用户自助生成，用于用户查找识别结果。
+        :param UsrAudioKey: 用户端对此任务的唯一标识。废弃参数，忽略即可。
         :type UsrAudioKey: str
         :param Url: 语音 URL，公网可下载。当 SourceType 值为 0（语音 URL上传） 时须填写该字段，为 1 时不填；URL 的长度大于 0，小于 2048，需进行urlencode编码。音频时长不能超过60s，音频文件大小不能超过3MB。
         :type Url: str
@@ -1191,8 +1189,8 @@ class SentenceRecognitionRequest(AbstractModel):
         :type Data: str
         :param DataLen: 数据长度，单位为字节。当 SourceType 值为1（本地语音数据上传）时必须填写，当 SourceType 值为0（语音 URL上传）可不写（此数据长度为数据未进行base64编码时的数据长度）。
         :type DataLen: int
-        :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
-        :type HotwordId: str
+        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
+        :type WordInfo: int
         :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
         :type FilterDirty: int
         :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
@@ -1201,8 +1199,10 @@ class SentenceRecognitionRequest(AbstractModel):
         :type FilterPunc: int
         :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1。
         :type ConvertNumMode: int
-        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
-        :type WordInfo: int
+        :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
+        :type HotwordId: str
+        :param CustomizationId: 自学习模型 id。如设置了该参数，将生效对应的自学习模型。
+        :type CustomizationId: str
         """
         self.ProjectId = None
         self.SubServiceType = None
@@ -1213,12 +1213,13 @@ class SentenceRecognitionRequest(AbstractModel):
         self.Url = None
         self.Data = None
         self.DataLen = None
-        self.HotwordId = None
+        self.WordInfo = None
         self.FilterDirty = None
         self.FilterModal = None
         self.FilterPunc = None
         self.ConvertNumMode = None
-        self.WordInfo = None
+        self.HotwordId = None
+        self.CustomizationId = None
 
 
     def _deserialize(self, params):
@@ -1231,12 +1232,13 @@ class SentenceRecognitionRequest(AbstractModel):
         self.Url = params.get("Url")
         self.Data = params.get("Data")
         self.DataLen = params.get("DataLen")
-        self.HotwordId = params.get("HotwordId")
+        self.WordInfo = params.get("WordInfo")
         self.FilterDirty = params.get("FilterDirty")
         self.FilterModal = params.get("FilterModal")
         self.FilterPunc = params.get("FilterPunc")
         self.ConvertNumMode = params.get("ConvertNumMode")
-        self.WordInfo = params.get("WordInfo")
+        self.HotwordId = params.get("HotwordId")
+        self.CustomizationId = params.get("CustomizationId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
