@@ -47,7 +47,7 @@ class CreateProbeTasksRequest(AbstractModel):
         :type ProbeType: int
         :param PluginSource: 插件类型
         :type PluginSource: str
-        :param ClientNum: 客户度ID
+        :param ClientNum: 客户端ID
         :type ClientNum: str
         """
         self.BatchTasks = None
@@ -219,9 +219,9 @@ AnalyzeTaskType_MediaStream：音视频体验
 	
 这里实际按拨测结果中的地区来填写即可
 
-国内一般是省级单位，如广东、广西、香港特区、新疆；直辖市则填北京、上海
+国内一般是省级单位，如广东、广西、中国香港、新疆；直辖市则填北京、上海
 
-海外一般是国家名，如澳大利亚、新加坡
+境外一般是国家名，如澳大利亚、新加坡
         :type Districts: list of str
         :param ErrorTypes: 错误类型
         :type ErrorTypes: list of str
@@ -319,7 +319,7 @@ class DescribeNodesRequest(AbstractModel):
         :param Location: 节点区域
 <li> 1 = 中国大陆 </li>
 <li> 2 = 港澳台 </li>
-<li> 3 = 海外 </li>
+<li> 3 = 境外</li>
         :type Location: int
         :param IsIPv6: 是否IPv6
         :type IsIPv6: bool
@@ -902,7 +902,7 @@ class NodeDefineExt(AbstractModel):
         :param Location: 区域
 <li> 1 = 中国大陆 </li>
 <li> 2 = 港澳台 </li>
-<li> 3 = 国外 </li>
+<li> 3 = 境外 </li>
 注意：此字段可能返回 null，表示取不到有效值。
         :type Location: int
         :param CodeType: 节点类型  如果为base 则为可用性拨测点，为空则为高级拨测点
@@ -1266,12 +1266,16 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         :type Parameters: str
         :param Cron: 定时任务cron表达式
         :type Cron: str
+        :param ResourceIDs: 预付费套餐id
+需要与taskId对应
+        :type ResourceIDs: list of str
         """
         self.TaskIds = None
         self.Nodes = None
         self.Interval = None
         self.Parameters = None
         self.Cron = None
+        self.ResourceIDs = None
 
 
     def _deserialize(self, params):
@@ -1280,6 +1284,7 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         self.Interval = params.get("Interval")
         self.Parameters = params.get("Parameters")
         self.Cron = params.get("Cron")
+        self.ResourceIDs = params.get("ResourceIDs")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
